yakumo.keystone.v2.endpoint.Manager

Package yakumo :: Package keystone :: Package v2 :: Module endpoint :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

manager class for endpoints on Identity V2 API

Nested Classes | [hide private]
| resource_class resource class for endpoints on Identity V2 API

Instance Methods | [hide private]
yakumo.keystone.v2.endpoint.Resource |
create(self, public_url=`'``__UNDEF__``'`, internal_url=`'``__UNDEF__``'`, admin_url=`'``__UNDEF__``'`, region=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`, service=`'``__UNDEF__``'`) Register endpoints for a service | source code
yakumo.base.Resource |
get(self, id) Aquire an existing resource object | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``identity``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _hidden_methods = ``[``'``update``'``]``
| _json_resource_key = ``'``endpoint``'``
| _json_resources_key = ``'``endpoints``'``
| _url_resource_path = ``'``/endpoints``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, public_url=`'``__UNDEF__``'`, internal_url=`'``__UNDEF__``'`, admin_url=`'``__UNDEF__``'`, region=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`, service=`'``__UNDEF__``'`) | source code
Register endpoints for a service Parameters: `public_url` (str) - URL of the public endpoint `internal_url` (str) - URL of the internal endpoint `admin_url` (str) - URL of the admin endpoint `region` (str) - Region name `is_enabled` (bool) - Whether the endpoints are enabled or not `service` (yakumo.keystone.v2.service.Resource) - Service Returns: yakumo.keystone.v2.endpoint.Resource Created endpoint Overrides: base.Manager.create

### get(self, id) | source code
Aquire an existing resource object Parameters: `id` - ID Returns: yakumo.base.Resource Resource object Overrides: base.Manager.get (inherited documentation)

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('public_url', 'publicurl', mapper.Noop),
      ('internal_url', 'internalurl', mapper.Noop), ('admin_url', 'adminurl'
      , mapper.Noop), ('region', 'region', mapper.Noop), ('is_enabled', 'ena
      bled', mapper.Noop), ('service', 'service_id', mapper.Resource('keysto
      ne.service')),]